@@ -5,7 +5,7 @@ author = {
 	"email":"maloja@krateng.dev",
 	"github": "krateng"
 }
-version = 2,4,3
+version = 2,4,5
 versionstr = ".".join(str(n) for n in version)
 links = {
 	"pypi":"malojaserver",
@@ -20,7 +20,8 @@ requires = [
 	"setproctitle>=1.1.10",
 	"wand>=0.5.4",
 	"lesscpy>=0.13",
-	"jinja2>2.11"
+	"jinja2>2.11",
+	"lru-dict>=1.1.16"
 ]
 resources = [
 	"web/*/*/*",
